@@ -160,6 +160,12 @@ data = {
                         "help": "create annotated tag instead of lightweight one",
                         "action": "store_true",
                     },
+                    {
+                        "name": ["--gpg-sign", "-s"],
+                        "help": "sign tag instead of lightweight one",
+                        "default": False,
+                        "action": "store_true",
+                    },
                     {
                         "name": ["--changelog-to-stdout"],
                         "action": "store_true",
