@@ -1,6 +1,8 @@
 import subprocess
 from typing import NamedTuple
 
+import chardet
+
 
 class Command(NamedTuple):
     out: str
@@ -20,4 +22,10 @@ def run(cmd: str) -> Command:
     )
     stdout, stderr = process.communicate()
     return_code = process.returncode
-    return Command(stdout.decode(), stderr.decode(), stdout, stderr, return_code)
+    return Command(
+        stdout.decode(chardet.detect(stdout)["encoding"] or "utf-8"),
+        stderr.decode(chardet.detect(stderr)["encoding"] or "utf-8"),
+        stdout,
+        stderr,
+        return_code,
+    )
